@@ -40,7 +40,7 @@ class ISchedule(Interface):
     
     length       = Int(title=u'Interval Length',     description=u'The measurement of time, in association with the Interval Unit, that is used to define the frequency of the billing occurrences.', max=365, required=True, default=1)
     unit         = Choice(title=u'Interval Units',   description=u'The unit of time, in association with the Interval Length, between each billing occurrence.', values=('months', 'days'), default='months', required=True)
-    start        = Datetime(title=u'Interval Start', description=u'The date the subscription begins (also the date the initial billing occurs).', required=True, default=datetime.datetime.now())
+    start        = Datetime(title=u'Interval Start', description=u'The date the subscription begins (also the date the initial billing occurs).', required=True, default=datetime.datetime.utcnow())
     cycles       = Int(title=u'Total Occurrences',   description=u'Number of billing occurrences or payments for the subscription.', min=1, max=9999, required=True, default=9999)
     trial_cycles = Int(title=u'Trial Occurrences',   description=u'Number of billing occurrences or payments in the trial period.', min=1, max=99, required=False)
 
